==> aws-cdk-lib-2.223.0-sources.jar: software/amazon/awscdk/services/lambda/CfnParametersCode.java <==
package software.amazon.awscdk.services.lambda;

/**
 * Lambda code defined using 2 CloudFormation parameters.
 * <p>
 * Useful when you don't have access to the code of your Lambda from your CDK code, so you can't use Assets,
 * and you want to deploy the Lambda in a CodePipeline, using CloudFormation Actions -
 * you can fill the parameters using the <code>#assign</code> method.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Stack lambdaStack = new Stack(app, "LambdaStack");
 * CfnParametersCode lambdaCode = Code.fromCfnParameters();
 * Function.Builder.create(lambdaStack, "Lambda")
 *         .code(lambdaCode)
 *         .handler("index.handler")
 *         .runtime(Runtime.NODEJS_LATEST)
 *         .build();
 * // other resources that your Lambda needs, added to the lambdaStack...
 * Stack pipelineStack = new Stack(app, "PipelineStack");
 * Pipeline pipeline = Pipeline.Builder.create(pipelineStack, "Pipeline")
 *         .crossAccountKeys(true)
 *         .build();
 * // add the source code repository containing this code to your Pipeline,
 * // and the source code of the Lambda Function, if they're separate
 * Artifact cdkSourceOutput = new Artifact();
 * CodeCommitSourceAction cdkSourceAction = CodeCommitSourceAction.Builder.create()
 *         .repository(Repository.Builder.create(pipelineStack, "CdkCodeRepo")
 *                 .repositoryName("CdkCodeRepo")
 *                 .build())
 *         .actionName("CdkCode_Source")
 *         .output(cdkSourceOutput)
 *         .build();
 * Artifact lambdaSourceOutput = new Artifact();
 * CodeCommitSourceAction lambdaSourceAction = CodeCommitSourceAction.Builder.create()
 *         .repository(Repository.Builder.create(pipelineStack, "LambdaCodeRepo")
 *                 .repositoryName("LambdaCodeRepo")
 *                 .build())
 *         .actionName("LambdaCode_Source")
 *         .output(lambdaSourceOutput)
 *         .build();
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("Source")
 *         .actions(List.of(cdkSourceAction, lambdaSourceAction))
 *         .build());
 * // synthesize the Lambda CDK template, using CodeBuild
 * // the below values are just examples, assuming your CDK code is in TypeScript/JavaScript -
 * // adjust the build environment and/or commands accordingly
 * Project cdkBuildProject = Project.Builder.create(pipelineStack, "CdkBuildProject")
 *         .environment(BuildEnvironment.builder()
 *                 .buildImage(LinuxBuildImage.STANDARD_7_0)
 *                 .build())
 *         .buildSpec(BuildSpec.fromObject(Map.of(
 *                 "version", "0.2",
 *                 "phases", Map.of(
 *                         "install", Map.of(
 *                                 "commands", "npm install"),
 *                         "build", Map.of(
 *                                 "commands", List.of("npm run build", "npm run cdk synth LambdaStack -- -o ."))),
 *                 "artifacts", Map.of(
 *                         "files", "LambdaStack.template.yaml"))))
 *         .build();
 * Artifact cdkBuildOutput = new Artifact();
 * CodeBuildAction cdkBuildAction = CodeBuildAction.Builder.create()
 *         .actionName("CDK_Build")
 *         .project(cdkBuildProject)
 *         .input(cdkSourceOutput)
 *         .outputs(List.of(cdkBuildOutput))
 *         .build();
 * // build your Lambda code, using CodeBuild
 * // again, this example assumes your Lambda is written in TypeScript/JavaScript -
 * // make sure to adjust the build environment and/or commands if they don't match your specific situation
 * Project lambdaBuildProject = Project.Builder.create(pipelineStack, "LambdaBuildProject")
 *         .environment(BuildEnvironment.builder()
 *                 .buildImage(LinuxBuildImage.STANDARD_7_0)
 *                 .build())
 *         .buildSpec(BuildSpec.fromObject(Map.of(
 *                 "version", "0.2",
 *                 "phases", Map.of(
 *                         "install", Map.of(
 *                                 "commands", "npm install"),
 *                         "build", Map.of(
 *                                 "commands", "npm run build")),
 *                 "artifacts", Map.of(
 *                         "files", List.of("index.js", "node_modules/**&#47;*")))))
 *         .build();
 * Artifact lambdaBuildOutput = new Artifact();
 * CodeBuildAction lambdaBuildAction = CodeBuildAction.Builder.create()
 *         .actionName("Lambda_Build")
 *         .project(lambdaBuildProject)
 *         .input(lambdaSourceOutput)
 *         .outputs(List.of(lambdaBuildOutput))
 *         .build();
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("Build")
 *         .actions(List.of(cdkBuildAction, lambdaBuildAction))
 *         .build());
 * // finally, deploy your Lambda Stack
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("Deploy")
 *         .actions(List.of(
 *             CloudFormationCreateUpdateStackAction.Builder.create()
 *                     .actionName("Lambda_CFN_Deploy")
 *                     .templatePath(cdkBuildOutput.atPath("LambdaStack.template.yaml"))
 *                     .stackName("LambdaStackDeployedName")
 *                     .adminPermissions(true)
 *                     .parameterOverrides(lambdaCode.assign(lambdaBuildOutput.getS3Location()))
 *                     .extraInputs(List.of(lambdaBuildOutput))
 *                     .build()))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.118.0 (build 02eec31)", date = "2025-11-10T13:40:08.767Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_lambda.CfnParametersCode")
public class CfnParametersCode extends software.amazon.awscdk.services.lambda.Code {

    protected CfnParametersCode(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CfnParametersCode(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public CfnParametersCode(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.CfnParametersCodeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public CfnParametersCode() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Create a parameters map from this instance's CloudFormation parameters.
     * <p>
     * It returns a map with 2 keys that correspond to the names of the parameters defined in this Lambda code,
     * and as values it contains the appropriate expressions pointing at the provided S3 location
     * (most likely, obtained from a CodePipeline Artifact by calling the <code>artifact.s3Location</code> method).
     * The result should be provided to the CloudFormation Action
     * that is deploying the Stack that the Lambda with this code is part of,
     * in the <code>parameterOverrides</code> property.
     * <p>
     * @param location the location of the object in S3 that represents the Lambda code. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> assign(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.Location location) {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.call(this, "assign", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)), new Object[] { java.util.Objects.requireNonNull(location, "location is required") }));
    }

    /**
     * Called when the lambda or layer is initialized to allow this object to bind to the stack, add resources and have fun.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.CodeConfig bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope) {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.CodeConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getBucketNameParam() {
        return software.amazon.jsii.Kernel.get(this, "bucketNameParam", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Determines whether this Code is inline code or not.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getIsInline() {
        return software.amazon.jsii.Kernel.get(this, "isInline", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getObjectKeyParam() {
        return software.amazon.jsii.Kernel.get(this, "objectKeyParam", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.lambda.CfnParametersCode}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.lambda.CfnParametersCode> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.lambda.CfnParametersCodeProps.Builder props;

        private Builder() {
        }

        /**
         * The CloudFormation parameter that represents the name of the S3 Bucket where the Lambda code will be located in.
         * <p>
         * Must be of type 'String'.
         * <p>
         * Default: a new parameter will be created
         * <p>
         * @return {@code this}
         * @param bucketNameParam The CloudFormation parameter that represents the name of the S3 Bucket where the Lambda code will be located in. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bucketNameParam(final software.amazon.awscdk.CfnParameter bucketNameParam) {
            this.props().bucketNameParam(bucketNameParam);
            return this;
        }

        /**
         * The CloudFormation parameter that represents the path inside the S3 Bucket where the Lambda code will be located at.
         * <p>
         * Must be of type 'String'.
         * <p>
         * Default: a new parameter will be created
         * <p>
         * @return {@code this}
         * @param objectKeyParam The CloudFormation parameter that represents the path inside the S3 Bucket where the Lambda code will be located at. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder objectKeyParam(final software.amazon.awscdk.CfnParameter objectKeyParam) {
            this.props().objectKeyParam(objectKeyParam);
            return this;
        }

        /**
         * The ARN of the KMS key used to encrypt the handler code.
         * <p>
         * Default: - the default server-side encryption with Amazon S3 managed keys(SSE-S3) key will be used.
         * <p>
         * @return {@code this}
         * @param sourceKmsKey The ARN of the KMS key used to encrypt the handler code. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceKmsKey(final software.amazon.awscdk.services.kms.IKeyRef sourceKmsKey) {
            this.props().sourceKmsKey(sourceKmsKey);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.lambda.CfnParametersCode}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.lambda.CfnParametersCode build() {
            return new software.amazon.awscdk.services.lambda.CfnParametersCode(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.lambda.CfnParametersCodeProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.lambda.CfnParametersCodeProps.Builder();
            }
            return this.props;
        }
    }
}

==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/services/lambda/CfnParametersCode.java <==
package software.amazon.awscdk.services.lambda;

/**
 * Lambda code defined using 2 CloudFormation parameters.
 * <p>
 * Useful when you don't have access to the code of your Lambda from your CDK code, so you can't use Assets,
 * and you want to deploy the Lambda in a CodePipeline, using CloudFormation Actions -
 * you can fill the parameters using the <code>#assign</code> method.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Stack lambdaStack = new Stack(app, "LambdaStack");
 * CfnParametersCode lambdaCode = Code.fromCfnParameters();
 * Function.Builder.create(lambdaStack, "Lambda")
 *         .code(lambdaCode)
 *         .handler("index.handler")
 *         .runtime(Runtime.NODEJS_LATEST)
 *         .build();
 * // other resources that your Lambda needs, added to the lambdaStack...
 * Stack pipelineStack = new Stack(app, "PipelineStack");
 * Pipeline pipeline = Pipeline.Builder.create(pipelineStack, "Pipeline")
 *         .crossAccountKeys(true)
 *         .build();
 * // add the source code repository containing this code to your Pipeline,
 * // and the source code of the Lambda Function, if they're separate
 * Artifact cdkSourceOutput = new Artifact();
 * CodeCommitSourceAction cdkSourceAction = CodeCommitSourceAction.Builder.create()
 *         .repository(Repository.Builder.create(pipelineStack, "CdkCodeRepo")
 *                 .repositoryName("CdkCodeRepo")
 *                 .build())
 *         .actionName("CdkCode_Source")
 *         .output(cdkSourceOutput)
 *         .build();
 * Artifact lambdaSourceOutput = new Artifact();
 * CodeCommitSourceAction lambdaSourceAction = CodeCommitSourceAction.Builder.create()
 *         .repository(Repository.Builder.create(pipelineStack, "LambdaCodeRepo")
 *                 .repositoryName("LambdaCodeRepo")
 *                 .build())
 *         .actionName("LambdaCode_Source")
 *         .output(lambdaSourceOutput)
 *         .build();
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("Source")
 *         .actions(List.of(cdkSourceAction, lambdaSourceAction))
 *         .build());
 * // synthesize the Lambda CDK template, using CodeBuild
 * // the below values are just examples, assuming your CDK code is in TypeScript/JavaScript -
 * // adjust the build environment and/or commands accordingly
 * Project cdkBuildProject = Project.Builder.create(pipelineStack, "CdkBuildProject")
 *         .environment(BuildEnvironment.builder()
 *                 .buildImage(LinuxBuildImage.STANDARD_7_0)
 *                 .build())
 *         .buildSpec(BuildSpec.fromObject(Map.of(
 *                 "version", "0.2",
 *                 "phases", Map.of(
 *                         "install", Map.of(
 *                                 "commands", "npm install"),
 *                         "build", Map.of(
 *                                 "commands", List.of("npm run build", "npm run cdk synth LambdaStack -- -o ."))),
 *                 "artifacts", Map.of(
 *                         "files", "LambdaStack.template.yaml"))))
 *         .build();
 * Artifact cdkBuildOutput = new Artifact();
 * CodeBuildAction cdkBuildAction = CodeBuildAction.Builder.create()
 *         .actionName("CDK_Build")
 *         .project(cdkBuildProject)
 *         .input(cdkSourceOutput)
 *         .outputs(List.of(cdkBuildOutput))
 *         .build();
 * // build your Lambda code, using CodeBuild
 * // again, this example assumes your Lambda is written in TypeScript/JavaScript -
 * // make sure to adjust the build environment and/or commands if they don't match your specific situation
 * Project lambdaBuildProject = Project.Builder.create(pipelineStack, "LambdaBuildProject")
 *         .environment(BuildEnvironment.builder()
 *                 .buildImage(LinuxBuildImage.STANDARD_7_0)
 *                 .build())
 *         .buildSpec(BuildSpec.fromObject(Map.of(
 *                 "version", "0.2",
 *                 "phases", Map.of(
 *                         "install", Map.of(
 *                                 "commands", "npm install"),
 *                         "build", Map.of(
 *                                 "commands", "npm run build")),
 *                 "artifacts", Map.of(
 *                         "files", List.of("index.js", "node_modules/**&#47;*")))))
 *         .build();
 * Artifact lambdaBuildOutput = new Artifact();
 * CodeBuildAction lambdaBuildAction = CodeBuildAction.Builder.create()
 *         .actionName("Lambda_Build")
 *         .project(lambdaBuildProject)
 *         .input(lambdaSourceOutput)
 *         .outputs(List.of(lambdaBuildOutput))
 *         .build();
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("Build")
 *         .actions(List.of(cdkBuildAction, lambdaBuildAction))
 *         .build());
 * // finally, deploy your Lambda Stack
 * pipeline.addStage(StageOptions.builder()
 *         .stageName("Deploy")
 *         .actions(List.of(
 *             CloudFormationCreateUpdateStackAction.Builder.create()
 *                     .actionName("Lambda_CFN_Deploy")
 *                     .templatePath(cdkBuildOutput.atPath("LambdaStack.template.yaml"))
 *                     .stackName("LambdaStackDeployedName")
 *                     .adminPermissions(true)
 *                     .parameterOverrides(lambdaCode.assign(lambdaBuildOutput.getS3Location()))
 *                     .extraInputs(List.of(lambdaBuildOutput))
 *                     .build()))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:40:54.865Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_lambda.CfnParametersCode")
public class CfnParametersCode extends software.amazon.awscdk.services.lambda.Code {

    protected CfnParametersCode(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CfnParametersCode(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public CfnParametersCode(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.CfnParametersCodeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public CfnParametersCode() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Create a parameters map from this instance's CloudFormation parameters.
     * <p>
     * It returns a map with 2 keys that correspond to the names of the parameters defined in this Lambda code,
     * and as values it contains the appropriate expressions pointing at the provided S3 location
     * (most likely, obtained from a CodePipeline Artifact by calling the <code>artifact.s3Location</code> method).
     * The result should be provided to the CloudFormation Action
     * that is deploying the Stack that the Lambda with this code is part of,
     * in the <code>parameterOverrides</code> property.
     * <p>
     * @param location the location of the object in S3 that represents the Lambda code. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> assign(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.Location location) {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.call(this, "assign", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)), new Object[] { java.util.Objects.requireNonNull(location, "location is required") }));
    }

    /**
     * Called when the lambda or layer is initialized to allow this object to bind to the stack, add resources and have fun.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.CodeConfig bind(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope) {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.CodeConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getBucketNameParam() {
        return software.amazon.jsii.Kernel.get(this, "bucketNameParam", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Determines whether this Code is inline code or not.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getIsInline() {
        return software.amazon.jsii.Kernel.get(this, "isInline", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getObjectKeyParam() {
        return software.amazon.jsii.Kernel.get(this, "objectKeyParam", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.lambda.CfnParametersCode}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.lambda.CfnParametersCode> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.lambda.CfnParametersCodeProps.Builder props;

        private Builder() {
        }

        /**
         * The CloudFormation parameter that represents the name of the S3 Bucket where the Lambda code will be located in.
         * <p>
         * Must be of type 'String'.
         * <p>
         * Default: a new parameter will be created
         * <p>
         * @return {@code this}
         * @param bucketNameParam The CloudFormation parameter that represents the name of the S3 Bucket where the Lambda code will be located in. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bucketNameParam(final software.amazon.awscdk.CfnParameter bucketNameParam) {
            this.props().bucketNameParam(bucketNameParam);
            return this;
        }

        /**
         * The CloudFormation parameter that represents the path inside the S3 Bucket where the Lambda code will be located at.
         * <p>
         * Must be of type 'String'.
         * <p>
         * Default: a new parameter will be created
         * <p>
         * @return {@code this}
         * @param objectKeyParam The CloudFormation parameter that represents the path inside the S3 Bucket where the Lambda code will be located at. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder objectKeyParam(final software.amazon.awscdk.CfnParameter objectKeyParam) {
            this.props().objectKeyParam(objectKeyParam);
            return this;
        }

        /**
         * The ARN of the KMS key used to encrypt the handler code.
         * <p>
         * Default: - the default server-side encryption with Amazon S3 managed keys(SSE-S3) key will be used.
         * <p>
         * @return {@code this}
         * @param sourceKmsKey The ARN of the KMS key used to encrypt the handler code. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceKmsKey(final software.amazon.awscdk.interfaces.kms.IKeyRef sourceKmsKey) {
            this.props().sourceKmsKey(sourceKmsKey);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.lambda.CfnParametersCode}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.lambda.CfnParametersCode build() {
            return new software.amazon.awscdk.services.lambda.CfnParametersCode(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.lambda.CfnParametersCodeProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.lambda.CfnParametersCodeProps.Builder();
            }
            return this.props;
        }
    }
}
